@@ -1,5 +1,5 @@
 package Net::Whois::Raw;
-$Net::Whois::Raw::VERSION = '2.99037';
+$Net::Whois::Raw::VERSION = '2.99042';
 # ABSTRACT: Get Whois information of domains and IP addresses.
 
 require 5.008_001;
@@ -178,7 +178,7 @@ sub recursive_whois {
         $registrar ||= /Registrar/ || /Registered through/;
 
         # Skip urls as recursive whois servers
-        if ( $registrar && !$norecurse && /whois server:\s*([a-z0-9\-_\.]+)\b/i ) {
+        if ( $registrar && !$norecurse && /whois server:\s*(?:https?:\/\/)?([a-z0-9\-_\.]+)\b/i ) {
             $newsrv = lc $1;
         }
         elsif ( $whois =~ /To single out one record, look it up with \"xxx\",/s ) {
@@ -191,7 +191,7 @@ sub recursive_whois {
         elsif ( /Contact information can be found in the (\S+)\s+database/ ) {
             $newsrv = $Net::Whois::Raw::Data::ip_whois_servers{ $1 };
         }
-        elsif ( ( /OrgID:\s+(\w+)/ || /descr:\s+(\w+)/ ) && Net::Whois::Raw::Common::is_ipaddr( $dom ) ) {
+        elsif ( ( /OrgID:\s+(\w+)/i || /descr:\s+(\w+)/ ) && Net::Whois::Raw::Common::is_ipaddr( $dom ) ) {
             my $val = $1;
             if ( $val =~ /^(?:RIPE|APNIC|KRNIC|LACNIC)$/ ) {
                 $newsrv = $Net::Whois::Raw::Data::ip_whois_servers{ $val };
@@ -308,7 +308,7 @@ sub whois_query {
 
             unless ( $sock ) {
                 $sock = IO::Socket::IP->new( @sockparams )
-                    or die "$srv: $!: " . join( ', ', @sockparams );
+                    or die "$srv: $IO::Socket::errstr: " . join( ', ', @sockparams );
             }
 
             if ($class->can ('whois_socket_fixup')) {
@@ -480,7 +480,7 @@ Net::Whois::Raw - Get Whois information of domains and IP addresses.
 
 =head1 VERSION
 
-version 2.99037
+version 2.99042
 
 =head1 SYNOPSIS
 
@@ -718,7 +718,7 @@ Alexander Nalobin <alexander@nalobin.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2002-2022 by Alexander Nalobin.
+This software is copyright (c) 2002-2025 by Alexander Nalobin.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
